#
# Conditional build:
%bcond_without	seccomp	# SecComp syscall filter
%bcond_without	lua	# Lua binding
%bcond_without	python	# Python binding

Summary:	Linux Container Tools
Summary(pl.UTF-8):	Narzędzia do kontenerów linuksowych (LXC)
Name:		lxc
Version:	0.9.0
Release:	5
License:	LGPL v2.1+
Group:		Applications/System
Source0:	http://lxc.sourceforge.net/download/lxc/%{name}-%{version}.tar.gz
# Source0-md5:	8552a4479090616f4bc04d8473765fc9
Patch0:		%{name}-devpts.patch
Patch1:		%{name}-pld.patch
Patch2:		am-1.14.patch
Patch3:		checkconfig-module.patch
Patch4:		checkconfig-vserver-config.patch
URL:		http://lxc.sourceforge.net/
BuildRequires:	autoconf >= 2.50
BuildRequires:	automake
BuildRequires:	docbook-dtd30-sgml
BuildRequires:	docbook-utils
BuildRequires:	docbook2X
BuildRequires:	libapparmor-devel
BuildRequires:	libcap-devel
%{?with_seccomp:BuildRequires:	libseccomp-devel}
%{?with_lua:BuildRequires:	lua51-devel >= 5.1}
BuildRequires:	pkgconfig
%{?with_python:BuildRequires:	python3-devel >= 3.2}
BuildRequires:	rpmbuild(macros) >= 1.612
BuildRequires:	sed >= 4.0
Suggests:	net-tools
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		configpath	/var/lib/lxc

%description
Tools to create and manage containers. It contains a full featured
container with the isolation / virtualization of the pids, the ipc,
the utsname, the mount points, /proc, /sys, the network and it takes
into account the control groups. It is very light, flexible, and
provides a set of tools around the container like the monitoring with
asynchronous events notification, or the freeze of the container. This
package is useful to create Virtual Private Server, or to run isolated
applications like bash or sshd.

%description -l pl.UTF-8
Narzędzia do tworzenia i zarządzania kontenerami. System ten obejmuje
w pełni funkcjonalne kontenery z ilozacją/wirtualizacją pidów, ipc,
utsname, punktów montowania, /proc, /sys, sieci oraz uwzględniające
grupy kontrolne. Jest bardzo lekki, elastyczny i udostępnia narzędzia
do czynności związanych z kontenerami, takich jak monitorowanie z
asynchronicznym powiadamianiem o zdarzeniach czy zamrażanie. Ten
pakiet jest przydatny do tworzenia wirtualnych serwerów prywatnych
oraz uruchamiania izolowanych aplikacji, takich jak bash czy sshd.

%package devel
Summary:	Header files for lxc library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki lxc
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Header files for lxc library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki lxc.

%package -n lua-lxc
Summary:	Lua binding for LXC
Summary(pl.UTF-8):	Wiązanie Lua do LXC
Group:		Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	lua51-libs >= 5.1

%description -n lua-lxc
Lua binding for LXC.

%description -n lua-lxc -l pl.UTF-8
Wiązanie Lua do LXC.

%package -n python3-lxc
Summary:	Python (3.x) binding for LXC
Summary(pl.UTF-8):	Wiązanie Pythona (3.x) do LXC
Group:		Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	python3-libs >= 3.2

%description -n python3-lxc
Python (3.x) binding for LXC.

%description -n python3-lxc -l pl.UTF-8
Wiązanie Pythona (3.x) do LXC.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%{__aclocal} -I config
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	db2xman=docbook2X2man \
	--disable-rpath \
	--enable-doc \
	%{?with_lua:--enable-lua} \
	%{?with_python:--enable-python} \
	%{?with_seccomp:--enable-seccomp} \
	--with-config-path=%{configpath} \
	--with-distro=pld

%{__make}
%{__make} -C doc

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	pcdatadir=%{_pkgconfigdir}

%{__make} -C doc install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} -r $RPM_BUILD_ROOT%{_docdir}

install -d $RPM_BUILD_ROOT%{configpath}

%if %{with python}
%py3_comp $RPM_BUILD_ROOT%{py3_sitedir}/lxc
%py3_ocomp $RPM_BUILD_ROOT%{py3_sitedir}/lxc
%endif
%if %{with lua}
%{__sed} -i -e '1s,#!/usr/bin/env lua,#!/usr/bin/lua51,' $RPM_BUILD_ROOT%{_bindir}/lxc-top
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog CONTRIBUTING MAINTAINERS README TODO doc/FAQ.txt doc/examples/*.conf
%attr(755,root,root) %{_bindir}/lxc-attach
%attr(755,root,root) %{_bindir}/lxc-cgroup
%attr(755,root,root) %{_bindir}/lxc-checkconfig
%attr(755,root,root) %{_bindir}/lxc-checkpoint
%attr(755,root,root) %{_bindir}/lxc-clone
%attr(755,root,root) %{_bindir}/lxc-console
%attr(755,root,root) %{_bindir}/lxc-create
%attr(755,root,root) %{_bindir}/lxc-destroy
%attr(755,root,root) %{_bindir}/lxc-execute
%attr(755,root,root) %{_bindir}/lxc-freeze
%attr(755,root,root) %{_bindir}/lxc-info
%attr(755,root,root) %{_bindir}/lxc-kill
%attr(755,root,root) %{_bindir}/lxc-monitor
%attr(755,root,root) %{_bindir}/lxc-netstat
%attr(755,root,root) %{_bindir}/lxc-ps
%attr(755,root,root) %{_bindir}/lxc-restart
%attr(755,root,root) %{_bindir}/lxc-shutdown
%attr(755,root,root) %{_bindir}/lxc-start
%attr(755,root,root) %{_bindir}/lxc-stop
%attr(755,root,root) %{_bindir}/lxc-unfreeze
%attr(755,root,root) %{_bindir}/lxc-unshare
%attr(755,root,root) %{_bindir}/lxc-version
%attr(755,root,root) %{_bindir}/lxc-wait
%attr(755,root,root) %{_libdir}/liblxc.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/liblxc.so.0
%dir %{configpath}
%dir %{_libdir}/lxc
%dir %{_libdir}/lxc/rootfs
%{_libdir}/lxc/rootfs/README
%attr(755,root,root) %{_libdir}/lxc/lxc-init
%dir %{_sysconfdir}/lxc
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/lxc/default.conf
%dir %{_datadir}/lxc
%{_datadir}/%{name}/lxc.functions
%dir %{_datadir}/%{name}/hooks
%dir %{_datadir}/%{name}/templates
%attr(755,root,root) %{_datadir}/%{name}/hooks/mount*
%attr(755,root,root) %{_datadir}/%{name}/templates/lxc-*
%{_mandir}/man1/lxc-attach.1*
%{_mandir}/man1/lxc-cgroup.1*
%{_mandir}/man1/lxc-checkconfig.1*
%{_mandir}/man1/lxc-checkpoint.1*
%{_mandir}/man1/lxc-clone.1*
%{_mandir}/man1/lxc-console.1*
%{_mandir}/man1/lxc-create.1*
%{_mandir}/man1/lxc-destroy.1*
%{_mandir}/man1/lxc-execute.1*
%{_mandir}/man1/lxc-freeze.1*
%{_mandir}/man1/lxc-info.1*
%{_mandir}/man1/lxc-kill.1*
%{_mandir}/man1/lxc-monitor.1*
%{_mandir}/man1/lxc-netstat.1*
%{_mandir}/man1/lxc-ps.1*
%{_mandir}/man1/lxc-restart.1*
%{_mandir}/man1/lxc-shutdown.1*
%{_mandir}/man1/lxc-start.1*
%{_mandir}/man1/lxc-stop.1*
%{_mandir}/man1/lxc-unfreeze.1*
%{_mandir}/man1/lxc-unshare.1*
%{_mandir}/man1/lxc-version.1*
%{_mandir}/man1/lxc-wait.1*
%{_mandir}/man5/lxc.conf.5*
%{_mandir}/man7/lxc.7*
%if %{without python}
# legacy version
%attr(755,root,root) %{_bindir}/lxc-ls
%{_mandir}/man1/lxc-ls.1*
%endif

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/liblxc.so
%{_includedir}/lxc
%{_pkgconfigdir}/lxc.pc

%if %{with lua}
%files -n lua-lxc
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/lxc-top
%dir %{_libdir}/lua/5.1/lxc
%attr(755,root,root) %{_libdir}/lua/5.1/lxc/core.so
%{_datadir}/lua/5.1/lxc.lua
%{_mandir}/man1/lxc-top.1*
%endif

%if %{with python}
%files -n python3-lxc
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/lxc-device
%attr(755,root,root) %{_bindir}/lxc-ls
%attr(755,root,root) %{_bindir}/lxc-start-ephemeral
%{py3_sitedir}/lxc
%attr(755,root,root) %{py3_sitedir}/_lxc.cpython-*.so
%{py3_sitedir}/_lxc-0.1-py*.egg-info
%{_mandir}/man1/lxc-device.1*
%{_mandir}/man1/lxc-ls.1*
%{_mandir}/man1/lxc-start-ephemeral.1*
%endif
%changelog
* Sat Nov 16 2013 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/lxc.git;a=log;h=master

* Sat Nov 16 2013 Elan Ruusamäe <glen@delfi.ee> f5933d4
- templates need to be executable

* Tue Sep 17 2013 Elan Ruusamäe <glen@delfi.ee> f73ef3b
- add usptream tracker url

* Tue Sep 17 2013 Elan Ruusamäe <glen@delfi.ee> bf6a07c
- fix parsing kernel version when kernel is vserver patched

* Tue Sep 17 2013 Elan Ruusamäe <glen@delfi.ee> 605f7b2
- add usptream bug url

* Tue Sep 17 2013 Elan Ruusamäe <glen@delfi.ee> 121019d
- give hint to user to modprobe configs (altho could just modprobe it?)

* Tue Sep 17 2013 Elan Ruusamäe <glen@delfi.ee> 92ccd5f
- fix for am 1.14

* Mon Sep 16 2013 Elan Ruusamäe <glen@delfi.ee> 21c5c66
- suggest net-tools, lxc-ps uses netstat(1)

* Thu Apr 18 2013 Jakub Bogusz <qboosh@pld-linux.org> c34ce68
- moved lua- and python-dependent scripts to lua- and python3- packages
- License is LGPL

* Wed Apr 17 2013 Jakub Bogusz <qboosh@pld-linux.org> 67c7022
- added pld patch
- enabled seccomp filter, lua and python bindings

* Mon Apr 15 2013 Aria Stewart <aredridel@nbtsc.org> a859d7b
- Up to 0.9.0

* Tue Mar 26 2013 Aria <aredridel@nbtsc.org> dc9a5b3
- 0.9.0.rc1

* Sun Oct 30 2011 Jan Rękorajski <baggins@pld-linux.org> 33aee79
- rel 2
- fix automounting /dev/pts

* Sun Oct 09 2011 Artur Frysiak <artur@frysiak.net> 03e91b5
- up to 0.7.5

* Thu May 26 2011 zbyniu <zbyniu@pld-linux.org> 3c74cff
- up to 0.7.4.2

* Sat Jan 29 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> 10f7ffd
- up to 0.7.3

* Sun Aug 08 2010 Adam Gołębiowski <adamg@pld-linux.org> a3918b6
- updated to 0.7.2

* Thu Jul 15 2010 mguevara <mguevara@pld-linux.org> 70f9d22
- up to 0.7.1-1

* Tue Apr 06 2010 sparky <sparky@pld-linux.org> 4e32c71
- BR: libcap-devel

* Tue Mar 23 2010 Zsolt Udvari <uzsolt@pld-linux.org> 670230e
- change URL
- more doc

* Tue Mar 23 2010 zbyniu <zbyniu@pld-linux.org> d7b4f26
- obsoleted

